<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>AboutDialog</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation>Un cliente de Jabber/XMPP sencillo y fácil de usar</translation>
    </message>
    <message>
        <source>License:</source>
        <translation>Licencia:</translation>
    </message>
    <message>
        <source>Source code on GitHub</source>
        <translation type="vanished">Código fuente en GitHub</translation>
    </message>
    <message>
        <source>View source code online</source>
        <translation>Vea el código fuente en línea</translation>
    </message>
    <message>
        <source>Report problems</source>
        <translation>Informar de problemas</translation>
    </message>
</context>
<context>
    <name>AboutSheet</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation type="vanished">Un cliente de Jabber/XMPP sencillo y fácil de usar</translation>
    </message>
    <message>
        <source>License:</source>
        <translation type="vanished">Licencia:</translation>
    </message>
    <message>
        <source>Source code on GitHub</source>
        <translation type="vanished">Código fuente en GitHub</translation>
    </message>
</context>
<context>
    <name>AccountDeletionFromClientAndServerConfirmationPage</name>
    <message>
        <source>Delete account completely</source>
        <translation type="vanished">Eliminar cuenta completamente</translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation type="vanished">Su cuenta se eliminará por completo, es decir, tanto de esta aplicación como del servidor.
No podrá utilizarla nuevamente.</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Eliminar</translation>
    </message>
</context>
<context>
    <name>AccountDeletionFromClientConfirmationPage</name>
    <message>
        <source>Remove account from this app</source>
        <translation type="vanished">Quitar cuenta de esta aplicación</translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
You won&apos;t be able to get your credentials back!
Make sure that you have backed up those if you want to use your account later.</source>
        <translation type="vanished">Se quitará su cuenta de esta aplicación.
No podrá recuperar sus datos de acceso.
Cerciórese de tener una copia de respaldo de estos si quiere utilizar su cuenta después.</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="vanished">Quitar</translation>
    </message>
</context>
<context>
    <name>AccountDeletionPage</name>
    <message>
        <source>Delete account</source>
        <translation type="vanished">Eliminar cuenta</translation>
    </message>
    <message>
        <source>You can remove your account &lt;b&gt;%1&lt;/b&gt; only from this app or delete it completely. If you delete your account completely, you won&apos;t be able to use it with another app because it is also removed from the server.</source>
        <translation type="vanished">Puede quitar la cuenta &lt;b&gt;%1&lt;/b&gt; de esta aplicación únicamente o eliminarla por completo. Si la elimina completamente, no podrá utilizarla en otras aplicaciones porque desaparecerá también del servidor.</translation>
    </message>
    <message>
        <source>Remove from this app</source>
        <translation type="vanished">Quitar de esta aplicación</translation>
    </message>
    <message>
        <source>Delete completely</source>
        <translation type="vanished">Eliminar completamente</translation>
    </message>
</context>
<context>
    <name>AccountSecurity</name>
    <message>
        <source>Account Security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable showing the password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable showing the QR-Code and password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccountTransferPage</name>
    <message>
        <source>Transfer account to another device</source>
        <translation>Transferir cuenta a otro dispositivo</translation>
    </message>
    <message>
        <source>Scan the QR code or enter the credentials as text on another device to log in on it.

Attention:
Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
        <translation>Escanee el código QR o proporcione los datos de acceso como texto en otro dispositivo para acceder a la cuenta.

Atención:
Jamás muestre este código QR a otras personas, dado que brinda acceso ilimitado a su cuenta.</translation>
    </message>
    <message>
        <source>Chat address:</source>
        <translation>Dirección de charla:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contraseña:</translation>
    </message>
    <message>
        <source>Hide QR code</source>
        <translation>Ocultar código QR</translation>
    </message>
    <message>
        <source>Show as QR code</source>
        <translation>Mostrar como código QR</translation>
    </message>
    <message>
        <source>Hide text</source>
        <translation>Ocultar texto</translation>
    </message>
    <message>
        <source>Show as text</source>
        <translation>Mostrar como texto</translation>
    </message>
</context>
<context>
    <name>BackButton</name>
    <message>
        <source>Navigate Back</source>
        <translation type="vanished">Navegar hacia atrás</translation>
    </message>
</context>
<context>
    <name>ChangePassword</name>
    <message>
        <source>Change password</source>
        <translation>Cambiar contraseña</translation>
    </message>
    <message>
        <source>Current password:</source>
        <translation>Contraseña actual:</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation>Contraseña nueva:</translation>
    </message>
    <message>
        <source>New password (repeat):</source>
        <translation>Contraseña nueva (repetir):</translation>
    </message>
    <message>
        <source>New passwords do not match.</source>
        <translation>Las contraseñas nuevas no coinciden.</translation>
    </message>
    <message>
        <source>Current password is invalid.</source>
        <translation>La contraseña actual no es válida.</translation>
    </message>
    <message>
        <source>You need to be connected to change your password.</source>
        <translation>Necesita conectarse para cambiar su contraseña.</translation>
    </message>
    <message>
        <source>After changing your password, you will need to reenter it on all your other devices.</source>
        <translation>Después de cambiar su contraseña, necesitará introducirla en todos sus dispositivos.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Cambiar</translation>
    </message>
</context>
<context>
    <name>ChatMessage</name>
    <message>
        <source>Message copied to clipboard</source>
        <translation type="vanished">Mensaje copiado al portapapeles</translation>
    </message>
    <message>
        <source>Copy Message</source>
        <translation type="vanished">Copiar mensaje</translation>
    </message>
    <message>
        <source>Edit Message</source>
        <translation type="vanished">Editar mensaje</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation>«Spoiler»</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Descargar</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="vanished">Copiar URL de descarga</translation>
    </message>
</context>
<context>
    <name>ChatMessageContextMenu</name>
    <message>
        <source>Copy message</source>
        <translation type="unfinished">Copiar mensaje</translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation type="unfinished">Editar mensaje</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="unfinished">Copiar URL de descarga</translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation type="unfinished">Citar mensaje</translation>
    </message>
</context>
<context>
    <name>ChatPage</name>
    <message>
        <source>Compose message</source>
        <translation>Crear mensaje</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="vanished">Enviar</translation>
    </message>
    <message>
        <source>Please choose a file to upload</source>
        <translation type="vanished">Elija un archivo para subir</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">Imagen</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Vídeo</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="vanished">Audio</translation>
    </message>
    <message>
        <source>Document</source>
        <translation type="vanished">Documento</translation>
    </message>
    <message>
        <source>Other file</source>
        <translation type="vanished">Otro archivo</translation>
    </message>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Elegir un archivo</translation>
    </message>
    <message>
        <source>Send a spoiler message</source>
        <translation>Enviar un mensaje de «spoiler»</translation>
    </message>
    <message>
        <source>Spoiler hint</source>
        <translation>Insinuación de «spoiler»</translation>
    </message>
    <message>
        <source>Unmute notifications</source>
        <translation>Restaurar notificaciones</translation>
    </message>
    <message>
        <source>Mute notifications</source>
        <translation>Silenciar notificaciones</translation>
    </message>
    <message>
        <source>View profile</source>
        <translation>Ver perfil</translation>
    </message>
    <message>
        <source>Multimedia settings</source>
        <translation type="vanished">Configuración de multimedia</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Buscar hacia arriba</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Buscar hacia abajo</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Todos los archivos</translation>
    </message>
    <message>
        <source>Copy message</source>
        <translation type="vanished">Copiar mensaje</translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation type="vanished">Editar mensaje</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="vanished">Copiar URL de descarga</translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation type="vanished">Citar mensaje</translation>
    </message>
</context>
<context>
    <name>ClientWorker</name>
    <message>
        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
        <translation>No se pudo eliminar la cuenta del servidor. Por ello, tampoco se ha quitado de esta aplicación: %1</translation>
    </message>
</context>
<context>
    <name>CommonEncoderSettings</name>
    <message>
        <source>Very low</source>
        <translation>Muy baja</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Baja</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <source>Very high</source>
        <translation>Muy alta</translation>
    </message>
    <message>
        <source>Constant quality</source>
        <translation>Calidad constante</translation>
    </message>
    <message>
        <source>Constant bit rate</source>
        <translation>Tasa de bits constante</translation>
    </message>
    <message>
        <source>Average bit rate</source>
        <translation>Tasa de bits promedio</translation>
    </message>
    <message>
        <source>Two pass</source>
        <translation>Dos pasadas</translation>
    </message>
</context>
<context>
    <name>ConfirmationPage</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>ContextDrawer</name>
    <message>
        <source>Actions</source>
        <translation type="vanished">Acciones</translation>
    </message>
</context>
<context>
    <name>DisablePasswordDisplay</name>
    <message>
        <source>Remove password completely</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your password will not be included in the QR code anymore.
You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisablePlainTextPasswordDisplay</name>
    <message>
        <source>Do not show password as text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your password will not be shown as text anymore.
You won&apos;t be able to see your password as text again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not show password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadJob</name>
    <message>
        <source>Could not save file: %1</source>
        <translation>No se pudo guardar el archivo: %1</translation>
    </message>
    <message>
        <source>Download failed: %1</source>
        <translation>Error de descarga: %1</translation>
    </message>
</context>
<context>
    <name>EmojiPicker</name>
    <message>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>People</source>
        <translation>Gente</translation>
    </message>
    <message>
        <source>Nature</source>
        <translation>Naturaleza</translation>
    </message>
    <message>
        <source>Food</source>
        <translation>Comida</translation>
    </message>
    <message>
        <source>Activity</source>
        <translation>Actividad</translation>
    </message>
    <message>
        <source>Travel</source>
        <translation>Viajes</translation>
    </message>
    <message>
        <source>Objects</source>
        <translation>Objetos</translation>
    </message>
    <message>
        <source>Symbols</source>
        <translation>Símbolos</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Banderas</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Search emoji</source>
        <translation>Buscar emoyi</translation>
    </message>
</context>
<context>
    <name>EmptyChatPage</name>
    <message>
        <source>Please select a chat to start messaging</source>
        <translation>Seleccione una charla para comenzar a mensajear</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Elegir un archivo</translation>
    </message>
</context>
<context>
    <name>FileChooserMobile</name>
    <message>
        <source>go to parent folder</source>
        <translation type="vanished">ir a la carpeta superior</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Cerrar</translation>
    </message>
    <message>
        <source>Go to parent folder</source>
        <translation type="vanished">Ir a la carpeta superior</translation>
    </message>
</context>
<context>
    <name>ForwardButton</name>
    <message>
        <source>Navigate Forward</source>
        <translation type="vanished">Navegar hacia adelante</translation>
    </message>
</context>
<context>
    <name>GlobalDrawer</name>
    <message>
        <source>Back</source>
        <translation type="vanished">Atrás</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation type="vanished">Salir</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>Invite friends</source>
        <translation>Invitar amigos</translation>
    </message>
    <message>
        <source>Invitation link copied to clipboard</source>
        <translation>Se copió el enlace de invitación en el portapapeles</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Desconectado</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>En línea</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Conectando…</translation>
    </message>
    <message>
        <source>Transfer account</source>
        <translation type="vanished">Transferir cuenta</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation type="vanished">Eliminar cuenta</translation>
    </message>
    <message>
        <source>Switch device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Kaidan</name>
    <message>
        <source>Could not send message, because not being connected.</source>
        <translation type="vanished">No se pudo enviar el mensaje porque no está conectado.</translation>
    </message>
    <message>
        <source>Could not add contact, because not being connected.</source>
        <translation type="vanished">No se pudo añadir el contacto porque no está conectado.</translation>
    </message>
    <message>
        <source>Could not remove contact, because not being connected.</source>
        <translation type="vanished">No se pudo eliminar el contacto porque no está conectado.</translation>
    </message>
    <message>
        <source>Could not send message, as a result of not being connected.</source>
        <translation type="vanished">No se pudo enviar el mensaje debido a que no está conectado.</translation>
    </message>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation type="vanished">No se pudo añadir el contacto debido a que no está conectado.</translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation type="vanished">No se pudo eliminar el contacto debido a que no está conectado.</translation>
    </message>
    <message>
        <source>The link will be opened after you have connected.</source>
        <extracomment>The link is an XMPP-URI (i.e. &apos;xmpp:kaidan@muc.kaidan.im?join&apos; for joining a chat)</extracomment>
        <translation>El enlace se abrirá después de que se haya conectado.</translation>
    </message>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation type="vanished">No se pudo enviar el archivo porque no está conectado.</translation>
    </message>
    <message>
        <source>No password found. Please enter it.</source>
        <translation type="vanished">No se encontró ninguna contraseña. Escríbala.</translation>
    </message>
    <message>
        <source>No valid login QR code found.</source>
        <translation>No se encontró ningún código QR de inicio de sesión válido.</translation>
    </message>
</context>
<context>
    <name>LocalAccountRemoval</name>
    <message>
        <source>Remove account from this app</source>
        <translation type="unfinished">Quitar cuenta de esta aplicación</translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished">Quitar</translation>
    </message>
</context>
<context>
    <name>LoginPage</name>
    <message>
        <source>Log in</source>
        <translation>Iniciar sesión</translation>
    </message>
    <message>
        <source>Log in to your XMPP account</source>
        <translation>Inicie sesión en su cuenta XMPP</translation>
    </message>
    <message>
        <source>Your Jabber-ID:</source>
        <translation type="vanished">Su Jabber-ID:</translation>
    </message>
    <message>
        <source>Your diaspora*-ID:</source>
        <translation type="vanished">Su diaspora*-ID:</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation type="vanished">usuario@example.org</translation>
    </message>
    <message>
        <source>user@diaspora.pod</source>
        <translation type="vanished">usuario@diaspora.pod</translation>
    </message>
    <message>
        <source>Your Password:</source>
        <translation type="vanished">Su contraseña:</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="vanished">Reintentar</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Conectando…</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation type="vanished">Usuario o contraseña no válido.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation type="vanished">No se puede conectar al servidor. Compruebe su conexión a internet.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation type="vanished">El servidor no admite conexiones seguras.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation type="vanished">Error al intentar conectar de forma segura.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your JID again.</source>
        <translation type="vanished">No se pudo resolver la dirección del servidor. Compruebe su JID de nuevo.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="vanished">No se pudo conectar al servidor.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation type="vanished">El protocolo de autenticación no es compatible con el servidor.</translation>
    </message>
    <message>
        <source>An unknown error occured; see log for details.</source>
        <translation type="vanished">Ha ocurrido un error desconocido; vea el registro para detalles.</translation>
    </message>
    <message>
        <source>Log in using a QR-Code</source>
        <translation type="vanished">Acceder mediante código QR</translation>
    </message>
</context>
<context>
    <name>MediaRecorder</name>
    <message>
        <source>Default</source>
        <translation>Predeterminado</translation>
    </message>
</context>
<context>
    <name>MediaUtils</name>
    <message>
        <source>Take picture</source>
        <translation>Hacer foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Grabar vídeo</translation>
    </message>
    <message>
        <source>Record voice</source>
        <translation>Grabar voz</translation>
    </message>
    <message>
        <source>Send location</source>
        <translation>Enviar ubicación</translation>
    </message>
    <message>
        <source>Choose file</source>
        <translation>Elegir archivo</translation>
    </message>
    <message>
        <source>Choose image</source>
        <translation>Elegir imagen</translation>
    </message>
    <message>
        <source>Choose video</source>
        <translation>Elegir vídeo</translation>
    </message>
    <message>
        <source>Choose audio file</source>
        <translation>Elegir archivo de audio</translation>
    </message>
    <message>
        <source>Choose document</source>
        <translation>Elegir documento</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Todos los archivos</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imágenes</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Audio files</source>
        <translation>Archivos de audio</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <translation>%1 (%2)</translation>
    </message>
</context>
<context>
    <name>MessageHandler</name>
    <message>
        <source>Could not send message, as a result of not being connected.</source>
        <translation type="vanished">No se pudo enviar el mensaje porque no está conectado.</translation>
    </message>
    <message>
        <source>Could not correct message, as a result of not being connected.</source>
        <translation type="vanished">No se pudo corregir el mensaje porque no está conectado.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="vanished">«Spoiler»</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation>No se pudo enviar el mensaje.</translation>
    </message>
    <message>
        <source>Message correction was not successful.</source>
        <translation>Falló la corrección del mensaje.</translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Pending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delivered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Error</translation>
    </message>
</context>
<context>
    <name>MultimediaSettings</name>
    <message>
        <source>Multimedia Settings</source>
        <translation>Configuración de multimedia</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation>Captura de imagen</translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation>Grabación de audio</translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation>Grabación de vídeo</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation>Entrada de audio</translation>
    </message>
    <message>
        <source>Container</source>
        <translation>Contenedor</translation>
    </message>
    <message>
        <source>Image</source>
        <translation>Imagen</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Códec</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolución</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Calidad</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation>Tasa de muestreo</translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation>Tasa de fotogramas</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Preparado</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>Iniciando…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>No disponible</translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation>Grabando…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>En pausa</translation>
    </message>
</context>
<context>
    <name>MultimediaSettingsPage</name>
    <message>
        <source>Multimedia Settings</source>
        <translation type="vanished">Configuración de multimedia</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation type="vanished">Configurar</translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation type="vanished">Captura de imagen</translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation type="vanished">Grabación de audio</translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation type="vanished">Grabación de vídeo</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="vanished">Cámara</translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation type="vanished">Entrada de audio</translation>
    </message>
    <message>
        <source>Container</source>
        <translation type="vanished">Contenedor</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">Imagen</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="vanished">Audio</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Vídeo</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation type="vanished">Códec</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="vanished">Resolución</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation type="vanished">Calidad</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation type="vanished">Tasa de muestreo</translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation type="vanished">Tasa de fotogramas</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation type="vanished">Preparado</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation type="vanished">Iniciando…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation type="vanished">No disponible</translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation type="vanished">Grabando…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="vanished">En pausa</translation>
    </message>
</context>
<context>
    <name>NewMedia</name>
    <message>
        <source>Ready</source>
        <translation>Preparado</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>Iniciando…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>No disponible</translation>
    </message>
    <message>
        <source>Recording… %1</source>
        <translation>Grabando… %1</translation>
    </message>
    <message>
        <source>Paused %1</source>
        <translation>%1 en pausa</translation>
    </message>
</context>
<context>
    <name>PasswordRemovalPage</name>
    <message>
        <source>Remove password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not show password as text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove completely</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Mark as read</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QmlUtils</name>
    <message>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation>Libre para charlar</translation>
    </message>
    <message>
        <source>Away</source>
        <translation>Ausente</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation>No molestar</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation>Ausente por bastante tiempo</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Desconectado</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation type="vanished">Invisible</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation>Usuario o contraseña no válido.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation>No se puede conectar con el servidor. Compruebe su conexión a internet.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation>El servidor no admite conexiones seguras.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation>Error al intentar conectar de forma segura.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your server name.</source>
        <translation>No se pudo resolver la dirección del servidor. Compruebe el nombre del servidor.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="obsolete">No se pudo conectar al servidor.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation>El servidor no admite el protocolo de autenticación.</translation>
    </message>
    <message>
        <source>This server does not support registration.</source>
        <translation>Este servidor no admite registros.</translation>
    </message>
    <message>
        <source>The server is offline or blocked by a firewall.</source>
        <translation>El servidor está desconectado o bloqueado por un cortafuegos.</translation>
    </message>
    <message>
        <source>The connection could not be refreshed.</source>
        <translation>No se pudo actualizar la conexión.</translation>
    </message>
    <message>
        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
        <translation>No se permite el acceso a internet. Compruebe la configuración de acceso a internet del sistema.</translation>
    </message>
</context>
<context>
    <name>QrCodeGenerator</name>
    <message>
        <source>Generating the QR code failed: %1</source>
        <translation>Falló la generación del código QR: %1</translation>
    </message>
</context>
<context>
    <name>QrCodeScannerPage</name>
    <message>
        <source>Scan QR code</source>
        <translation>Escanear código QR</translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation>No hay ninguna cámara disponible.</translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation>La cámara está ocupada.
Pruebe a cerrar otras aplicaciones que utilicen la cámara.</translation>
    </message>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation>No se admite el formato «%1» de la cámara.</translation>
    </message>
    <message>
        <source>Logging in…</source>
        <translation type="vanished">Accediendo…</translation>
    </message>
    <message>
        <source>Scan the QR code from your existing device to transfer your account.</source>
        <translation>Escanee el código QR desde su dispositivo existente para transferir su cuenta.</translation>
    </message>
    <message>
        <source>Show explanation</source>
        <translation>Mostrar explicación</translation>
    </message>
    <message>
        <source>Scan</source>
        <translation>Escanear</translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation>Continuar sin código QR</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="unfinished">Conectando…</translation>
    </message>
</context>
<context>
    <name>RegistrationLoginDecisionPage</name>
    <message>
        <source>Set up</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <source>Register a new account</source>
        <translation>Registrar cuenta nueva</translation>
    </message>
    <message>
        <source>Use an existing account</source>
        <translation>Utilizar cuenta existente</translation>
    </message>
</context>
<context>
    <name>RegistrationManager</name>
    <message>
        <source>Password changed successfully.</source>
        <translation>Contraseña cambiada con éxito.</translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation>Error al cambiar la contraseña: %1</translation>
    </message>
</context>
<context>
    <name>RemoteAccountDeletion</name>
    <message>
        <source>Delete account completely</source>
        <translation type="unfinished">Eliminar cuenta completamente</translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation type="unfinished">Su cuenta se eliminará por completo, es decir, tanto de esta aplicación como del servidor.
No podrá utilizarla nuevamente.</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterAddContactSheet</name>
    <message>
        <source>Add new contact</source>
        <translation>Añadir contacto nuevo</translation>
    </message>
    <message>
        <source>Nickname:</source>
        <translation>Apodo:</translation>
    </message>
    <message>
        <source>Jabber-ID:</source>
        <translation>Id. de Jabber:</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation>usuario@example.org</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <source>This will also send a request to access the presence of the contact.</source>
        <translation>Esto también enviará una solicitud para acceder a la presencia del contacto.</translation>
    </message>
    <message>
        <source>Optional message:</source>
        <translation>Mensaje opcional:</translation>
    </message>
    <message>
        <source>Tell your chat partner who you are.</source>
        <translation>Diga a su interlocutor/a quién es usted.</translation>
    </message>
</context>
<context>
    <name>RosterListItem</name>
    <message>
        <source>Error: Please check the JID.</source>
        <translation>Error: compruebe el JID.</translation>
    </message>
    <message>
        <source>Available</source>
        <translation type="vanished">Disponible</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="vanished">Libre para chatear</translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="vanished">Ausente</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="vanished">No molestar</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="vanished">Ausente por bastante tiempo</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="vanished">Desconectado</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Error</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation type="vanished">No válido</translation>
    </message>
</context>
<context>
    <name>RosterManager</name>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation>No se pudo añadir el contacto porque no está conectado.</translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation>No se pudo eliminar el contacto porque no está conectado.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation>«Spoiler»</translation>
    </message>
    <message>
        <source>Could not rename contact, as a result of not being connected.</source>
        <translation>No se pudo cambiar el nombre del contacto porque no está conectado.</translation>
    </message>
</context>
<context>
    <name>RosterPage</name>
    <message>
        <source>Contacts</source>
        <translation>Contactos</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation>Añadir nuevo contacto</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Conectando…</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Desconectado</translation>
    </message>
    <message>
        <source>Search contacts</source>
        <translation>Buscar contactos</translation>
    </message>
</context>
<context>
    <name>RosterRemoveContactSheet</name>
    <message>
        <source>Do you really want to delete the contact &quot;%1&quot; from your roster?</source>
        <translation type="vanished">¿Realmente desea eliminar el contacto &quot;%1&quot; de su lista?</translation>
    </message>
    <message>
        <source>Delete contact</source>
        <translation>Borrar contacto</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;%1&gt; from your roster?</source>
        <translation type="vanished">¿Realmente desea borrar el contacto &lt;%1&gt; de su lista?</translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
        <translation>¿Realmente desea eliminar el contacto &lt;b&gt;%1&lt;/b&gt; de su lista?</translation>
    </message>
</context>
<context>
    <name>RosterRenameContactSheet</name>
    <message>
        <source>Rename contact</source>
        <translation>Cambiar nombre de contacto</translation>
    </message>
    <message>
        <source>Edit name:</source>
        <translation type="vanished">Editar nombre:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Cambiar nombre</translation>
    </message>
</context>
<context>
    <name>SendMediaSheet</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>Caption</source>
        <translation>Título</translation>
    </message>
</context>
<context>
    <name>ServerListModel</name>
    <message>
        <source>Custom server</source>
        <translation>Servidor personalizado</translation>
    </message>
    <message>
        <source>No limitation</source>
        <extracomment>Unlimited file size for uploading files
----------
Deletion of message history saved on server</extracomment>
        <translation>Sin límites</translation>
    </message>
    <message>
        <source>%1 days</source>
        <translation>%1 días</translation>
    </message>
</context>
<context>
    <name>SettingsContent</name>
    <message>
        <source>Change password</source>
        <translation>Cambiar contraseña</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation>Cambia la contraseña de su cuenta. Necesitará introducirla en todos sus dispositivos.</translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation>Configuración de multimedia</translation>
    </message>
    <message>
        <source>Configure photo, video and audio recording settings</source>
        <translation>Defina las opciones de grabación de imágenes, vídeo y audio</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished">Configuración</translation>
    </message>
    <message>
        <source>Account security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>configure whether this device can be used to log in on a new device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove account from Kaidan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove account from this app</source>
        <translation type="unfinished">Quitar cuenta de esta aplicación</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation type="unfinished">Eliminar cuenta</translation>
    </message>
    <message>
        <source>Delete account from the server</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Settings</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <source>Change password</source>
        <translation type="vanished">Cambiar contraseña</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation type="vanished">Cambia la contraseña de su cuenta. Necesitará introducirla en todos sus dispositivos.</translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation type="obsolete">Configuración de multimedia</translation>
    </message>
</context>
<context>
    <name>SettingsSheet</name>
    <message>
        <source>Settings</source>
        <translation type="vanished">Configuración</translation>
    </message>
</context>
<context>
    <name>StartPage</name>
    <message>
        <source>Enjoy free communication on every device!</source>
        <translation>Disfrute de comunicación libre y gratuita en cualquier dispositivo.</translation>
    </message>
    <message>
        <source>Let&apos;s start</source>
        <translation>Empezar</translation>
    </message>
</context>
<context>
    <name>SubRequestAcceptSheet</name>
    <message>
        <source>Subscription Request</source>
        <translation>Solicitud de suscripción</translation>
    </message>
    <message>
        <source>You received a subscription request by &lt;b&gt;%1&lt;/b&gt;. If you accept it, the account will have access to your presence status.</source>
        <translation>Ha recibido una solicitud de suscripción de &lt;b&gt;%1&lt;/b&gt;. Si la acepta, la cuenta tendrá acceso a su estado de presencia.</translation>
    </message>
    <message>
        <source>Decline</source>
        <translation>Rechazar</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>ToolBarApplicationHeader</name>
    <message>
        <source>More Actions</source>
        <translation type="vanished">Más acciones</translation>
    </message>
</context>
<context>
    <name>ToolBarPageHeader</name>
    <message>
        <source>More Actions</source>
        <translation type="vanished">Más acciones</translation>
    </message>
</context>
<context>
    <name>UploadManager</name>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation>No se pudo enviar el archivo porque no está conectado.</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Archivo</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation type="unfinished">No se pudo enviar el mensaje.</translation>
    </message>
</context>
<context>
    <name>UserProfilePage</name>
    <message>
        <source>Profile</source>
        <translation>Perfil</translation>
    </message>
</context>
<context>
    <name>VCardModel</name>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Apodo</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Correo electrónico</translation>
    </message>
    <message>
        <source>Birthday</source>
        <translation>Cumpleaños</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Sitio web</translation>
    </message>
</context>
</TS>
